@@ -25,14 +25,14 @@ class EnviarPedido(Enviar):
             notification_url=notification_url,
             external_reference=self.pedido.numero,
             payer=Payer(
-                name=unicode(self.pedido.cliente.nome.split()[0]),
-                surname=unicode(self.pedido.cliente.nome.split()[-1]),
+                name=self.formatador.trata_unicode_com_limite(self.pedido.cliente.nome.split()[0]),
+                surname=self.formatador.trata_unicode_com_limite(self.pedido.cliente.nome.split()[-1]),
                 email=self.pedido.cliente.email,
                 date_created=self.formatador.formata_data(self.pedido.cliente.data_criacao, iso=True),
                 phone=self.telefone,
                 identification=self.identificacao,
                 address=PayerAddress(
-                    street_name=unicode(self.pedido.cliente.endereco.endereco),
+                    street_name=self.formatador.trata_unicode_com_limite(self.pedido.cliente.endereco.endereco),
                     street_number=self.pedido.cliente.endereco.numero,
                     zip_code=self.pedido.cliente.endereco.cep,
                 )
@@ -45,9 +45,9 @@ class EnviarPedido(Enviar):
             shipments=Shipments(
                 cost=self.formatador.formata_decimal(self.valor_envio, como_float=True),
                 receiver_address=ReceiverAddress(
-                    street_name=unicode(self.pedido.endereco_entrega.endereco),
+                    street_name=self.formatador.trata_unicode_com_limite(self.pedido.endereco_entrega.endereco),
                     street_number=self.pedido.endereco_entrega.numero,
-                    apartment=unicode(self.pedido.endereco_entrega.complemento),
+                    apartment=self.formatador.trata_unicode_com_limite(self.pedido.endereco_entrega.complemento),
                     zip_code=self.pedido.endereco_entrega.cep,
                 )
             ),
@@ -87,8 +87,8 @@ class EnviarPedido(Enviar):
     def items(self):
         items = [
             Item(
-                id=unicode(item.sku),
-                title=unicode(item.nome),
+                id=self.formatador.trata_unicode_com_limite(item.sku),
+                title=self.formatador.trata_unicode_com_limite(item.nome),
                 currency_id="BRL",
                 unit_price=self.formatador.formata_decimal(item.preco_venda, como_float=True),
                 quantity=self.formatador.formata_decimal(item.quantidade, como_float=True),
